# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from .meta_pb2 import (
    TransactionResult as org___xrpl___rpc___v1___meta_pb2___TransactionResult,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    Union as typing___Union,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


class SubmitTransactionRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    signed_transaction = ... # type: builtin___bytes
    fail_hard = ... # type: builtin___bool

    def __init__(self,
        *,
        signed_transaction : typing___Optional[builtin___bytes] = None,
        fail_hard : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> SubmitTransactionRequest: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> SubmitTransactionRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"fail_hard",u"signed_transaction"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"fail_hard",b"fail_hard",u"signed_transaction",b"signed_transaction"]) -> None: ...

class SubmitTransactionResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    engine_result_code = ... # type: builtin___int
    engine_result_message = ... # type: typing___Text
    hash = ... # type: builtin___bytes

    @property
    def engine_result(self) -> org___xrpl___rpc___v1___meta_pb2___TransactionResult: ...

    def __init__(self,
        *,
        engine_result : typing___Optional[org___xrpl___rpc___v1___meta_pb2___TransactionResult] = None,
        engine_result_code : typing___Optional[builtin___int] = None,
        engine_result_message : typing___Optional[typing___Text] = None,
        hash : typing___Optional[builtin___bytes] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> SubmitTransactionResponse: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> SubmitTransactionResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"engine_result"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"engine_result",u"engine_result_code",u"engine_result_message",u"hash"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"engine_result",b"engine_result"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"engine_result",b"engine_result",u"engine_result_code",b"engine_result_code",u"engine_result_message",b"engine_result_message",u"hash",b"hash"]) -> None: ...
