# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/ledger.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/ledger.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n\x1corg/xrpl/rpc/v1/ledger.proto\x12\x0forg.xrpl.rpc.v1\"\xe7\x01\n\x0fLedgerSpecifier\x12=\n\x08shortcut\x18\x01 \x01(\x0e\x32).org.xrpl.rpc.v1.LedgerSpecifier.ShortcutH\x00\x12\x12\n\x08sequence\x18\x02 \x01(\rH\x00\x12\x0e\n\x04hash\x18\x03 \x01(\x0cH\x00\"g\n\x08Shortcut\x12\x18\n\x14SHORTCUT_UNSPECIFIED\x10\x00\x12\x16\n\x12SHORTCUT_VALIDATED\x10\x01\x12\x13\n\x0fSHORTCUT_CLOSED\x10\x02\x12\x14\n\x10SHORTCUT_CURRENT\x10\x03\x42\x08\n\x06ledger\"A\n\x0bLedgerRange\x12\x18\n\x10ledger_index_min\x18\x01 \x01(\r\x12\x18\n\x10ledger_index_max\x18\x02 \x01(\rB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
)



_LEDGERSPECIFIER_SHORTCUT = _descriptor.EnumDescriptor(
  name='Shortcut',
  full_name='org.xrpl.rpc.v1.LedgerSpecifier.Shortcut',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SHORTCUT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHORTCUT_VALIDATED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHORTCUT_CLOSED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHORTCUT_CURRENT', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=168,
  serialized_end=271,
)
_sym_db.RegisterEnumDescriptor(_LEDGERSPECIFIER_SHORTCUT)


_LEDGERSPECIFIER = _descriptor.Descriptor(
  name='LedgerSpecifier',
  full_name='org.xrpl.rpc.v1.LedgerSpecifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shortcut', full_name='org.xrpl.rpc.v1.LedgerSpecifier.shortcut', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence', full_name='org.xrpl.rpc.v1.LedgerSpecifier.sequence', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='org.xrpl.rpc.v1.LedgerSpecifier.hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LEDGERSPECIFIER_SHORTCUT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='ledger', full_name='org.xrpl.rpc.v1.LedgerSpecifier.ledger',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=50,
  serialized_end=281,
)


_LEDGERRANGE = _descriptor.Descriptor(
  name='LedgerRange',
  full_name='org.xrpl.rpc.v1.LedgerRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_index_min', full_name='org.xrpl.rpc.v1.LedgerRange.ledger_index_min', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_index_max', full_name='org.xrpl.rpc.v1.LedgerRange.ledger_index_max', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=283,
  serialized_end=348,
)

_LEDGERSPECIFIER.fields_by_name['shortcut'].enum_type = _LEDGERSPECIFIER_SHORTCUT
_LEDGERSPECIFIER_SHORTCUT.containing_type = _LEDGERSPECIFIER
_LEDGERSPECIFIER.oneofs_by_name['ledger'].fields.append(
  _LEDGERSPECIFIER.fields_by_name['shortcut'])
_LEDGERSPECIFIER.fields_by_name['shortcut'].containing_oneof = _LEDGERSPECIFIER.oneofs_by_name['ledger']
_LEDGERSPECIFIER.oneofs_by_name['ledger'].fields.append(
  _LEDGERSPECIFIER.fields_by_name['sequence'])
_LEDGERSPECIFIER.fields_by_name['sequence'].containing_oneof = _LEDGERSPECIFIER.oneofs_by_name['ledger']
_LEDGERSPECIFIER.oneofs_by_name['ledger'].fields.append(
  _LEDGERSPECIFIER.fields_by_name['hash'])
_LEDGERSPECIFIER.fields_by_name['hash'].containing_oneof = _LEDGERSPECIFIER.oneofs_by_name['ledger']
DESCRIPTOR.message_types_by_name['LedgerSpecifier'] = _LEDGERSPECIFIER
DESCRIPTOR.message_types_by_name['LedgerRange'] = _LEDGERRANGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LedgerSpecifier = _reflection.GeneratedProtocolMessageType('LedgerSpecifier', (_message.Message,), {
  'DESCRIPTOR' : _LEDGERSPECIFIER,
  '__module__' : 'org.xrpl.rpc.v1.ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.LedgerSpecifier)
  })
_sym_db.RegisterMessage(LedgerSpecifier)

LedgerRange = _reflection.GeneratedProtocolMessageType('LedgerRange', (_message.Message,), {
  'DESCRIPTOR' : _LEDGERRANGE,
  '__module__' : 'org.xrpl.rpc.v1.ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.LedgerRange)
  })
_sym_db.RegisterMessage(LedgerRange)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
