# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/get_fee.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import amount_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/get_fee.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n\x1dorg/xrpl/rpc/v1/get_fee.proto\x12\x0forg.xrpl.rpc.v1\x1a\x1corg/xrpl/rpc/v1/amount.proto\"\x0f\n\rGetFeeRequest\"\xfc\x01\n\x0eGetFeeResponse\x12\x1f\n\x13\x63urrent_ledger_size\x18\x01 \x01(\x04\x42\x02\x30\x01\x12\x1e\n\x12\x63urrent_queue_size\x18\x02 \x01(\x04\x42\x02\x30\x01\x12!\n\x03\x66\x65\x65\x18\x03 \x01(\x0b\x32\x14.org.xrpl.rpc.v1.Fee\x12 \n\x14\x65xpected_ledger_size\x18\x04 \x01(\x04\x42\x02\x30\x01\x12\x1c\n\x14ledger_current_index\x18\x05 \x01(\r\x12*\n\x06levels\x18\x06 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.FeeLevels\x12\x1a\n\x0emax_queue_size\x18\x07 \x01(\x04\x42\x02\x30\x01\"\xdd\x01\n\x03\x46\x65\x65\x12\x31\n\x08\x62\x61se_fee\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.XRPDropsAmount\x12\x33\n\nmedian_fee\x18\x02 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.XRPDropsAmount\x12\x34\n\x0bminimum_fee\x18\x03 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.XRPDropsAmount\x12\x38\n\x0fopen_ledger_fee\x18\x04 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.XRPDropsAmount\"|\n\tFeeLevels\x12\x18\n\x0cmedian_level\x18\x01 \x01(\x04\x42\x02\x30\x01\x12\x19\n\rminimum_level\x18\x02 \x01(\x04\x42\x02\x30\x01\x12\x1d\n\x11open_ledger_level\x18\x03 \x01(\x04\x42\x02\x30\x01\x12\x1b\n\x0freference_level\x18\x04 \x01(\x04\x42\x02\x30\x01\x42\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2.DESCRIPTOR,])




_GETFEEREQUEST = _descriptor.Descriptor(
  name='GetFeeRequest',
  full_name='org.xrpl.rpc.v1.GetFeeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=95,
)


_GETFEERESPONSE = _descriptor.Descriptor(
  name='GetFeeResponse',
  full_name='org.xrpl.rpc.v1.GetFeeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_ledger_size', full_name='org.xrpl.rpc.v1.GetFeeResponse.current_ledger_size', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_queue_size', full_name='org.xrpl.rpc.v1.GetFeeResponse.current_queue_size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee', full_name='org.xrpl.rpc.v1.GetFeeResponse.fee', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expected_ledger_size', full_name='org.xrpl.rpc.v1.GetFeeResponse.expected_ledger_size', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_current_index', full_name='org.xrpl.rpc.v1.GetFeeResponse.ledger_current_index', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='levels', full_name='org.xrpl.rpc.v1.GetFeeResponse.levels', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_queue_size', full_name='org.xrpl.rpc.v1.GetFeeResponse.max_queue_size', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=350,
)


_FEE = _descriptor.Descriptor(
  name='Fee',
  full_name='org.xrpl.rpc.v1.Fee',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_fee', full_name='org.xrpl.rpc.v1.Fee.base_fee', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='median_fee', full_name='org.xrpl.rpc.v1.Fee.median_fee', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minimum_fee', full_name='org.xrpl.rpc.v1.Fee.minimum_fee', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_ledger_fee', full_name='org.xrpl.rpc.v1.Fee.open_ledger_fee', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=353,
  serialized_end=574,
)


_FEELEVELS = _descriptor.Descriptor(
  name='FeeLevels',
  full_name='org.xrpl.rpc.v1.FeeLevels',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='median_level', full_name='org.xrpl.rpc.v1.FeeLevels.median_level', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minimum_level', full_name='org.xrpl.rpc.v1.FeeLevels.minimum_level', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_ledger_level', full_name='org.xrpl.rpc.v1.FeeLevels.open_ledger_level', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_level', full_name='org.xrpl.rpc.v1.FeeLevels.reference_level', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=576,
  serialized_end=700,
)

_GETFEERESPONSE.fields_by_name['fee'].message_type = _FEE
_GETFEERESPONSE.fields_by_name['levels'].message_type = _FEELEVELS
_FEE.fields_by_name['base_fee'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._XRPDROPSAMOUNT
_FEE.fields_by_name['median_fee'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._XRPDROPSAMOUNT
_FEE.fields_by_name['minimum_fee'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._XRPDROPSAMOUNT
_FEE.fields_by_name['open_ledger_fee'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._XRPDROPSAMOUNT
DESCRIPTOR.message_types_by_name['GetFeeRequest'] = _GETFEEREQUEST
DESCRIPTOR.message_types_by_name['GetFeeResponse'] = _GETFEERESPONSE
DESCRIPTOR.message_types_by_name['Fee'] = _FEE
DESCRIPTOR.message_types_by_name['FeeLevels'] = _FEELEVELS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetFeeRequest = _reflection.GeneratedProtocolMessageType('GetFeeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEEREQUEST,
  '__module__' : 'org.xrpl.rpc.v1.get_fee_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetFeeRequest)
  })
_sym_db.RegisterMessage(GetFeeRequest)

GetFeeResponse = _reflection.GeneratedProtocolMessageType('GetFeeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEERESPONSE,
  '__module__' : 'org.xrpl.rpc.v1.get_fee_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetFeeResponse)
  })
_sym_db.RegisterMessage(GetFeeResponse)

Fee = _reflection.GeneratedProtocolMessageType('Fee', (_message.Message,), {
  'DESCRIPTOR' : _FEE,
  '__module__' : 'org.xrpl.rpc.v1.get_fee_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Fee)
  })
_sym_db.RegisterMessage(Fee)

FeeLevels = _reflection.GeneratedProtocolMessageType('FeeLevels', (_message.Message,), {
  'DESCRIPTOR' : _FEELEVELS,
  '__module__' : 'org.xrpl.rpc.v1.get_fee_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.FeeLevels)
  })
_sym_db.RegisterMessage(FeeLevels)


DESCRIPTOR._options = None
_GETFEERESPONSE.fields_by_name['current_ledger_size']._options = None
_GETFEERESPONSE.fields_by_name['current_queue_size']._options = None
_GETFEERESPONSE.fields_by_name['expected_ledger_size']._options = None
_GETFEERESPONSE.fields_by_name['max_queue_size']._options = None
_FEELEVELS.fields_by_name['median_level']._options = None
_FEELEVELS.fields_by_name['minimum_level']._options = None
_FEELEVELS.fields_by_name['open_ledger_level']._options = None
_FEELEVELS.fields_by_name['reference_level']._options = None
# @@protoc_insertion_point(module_scope)
