# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/get_account_info.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ledger_objects_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2
from . import amount_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2
from . import account_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2
from . import ledger_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2
from . import common_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/get_account_info.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n&org/xrpl/rpc/v1/get_account_info.proto\x12\x0forg.xrpl.rpc.v1\x1a$org/xrpl/rpc/v1/ledger_objects.proto\x1a\x1corg/xrpl/rpc/v1/amount.proto\x1a\x1dorg/xrpl/rpc/v1/account.proto\x1a\x1corg/xrpl/rpc/v1/ledger.proto\x1a\x1corg/xrpl/rpc/v1/common.proto\"\xb0\x01\n\x15GetAccountInfoRequest\x12\x30\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.AccountAddress\x12\x0e\n\x06strict\x18\x02 \x01(\x08\x12\x30\n\x06ledger\x18\x03 \x01(\x0b\x32 .org.xrpl.rpc.v1.LedgerSpecifier\x12\r\n\x05queue\x18\x04 \x01(\x08\x12\x14\n\x0csigner_lists\x18\x05 \x01(\x08\"\xd7\x01\n\x16GetAccountInfoResponse\x12\x32\n\x0c\x61\x63\x63ount_data\x18\x01 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.AccountRoot\x12\x30\n\x0bsigner_list\x18\x02 \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.SignerList\x12\x14\n\x0cledger_index\x18\x03 \x01(\r\x12.\n\nqueue_data\x18\x04 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.QueueData\x12\x11\n\tvalidated\x18\x05 \x01(\x08\"\xe7\x01\n\tQueueData\x12\x11\n\ttxn_count\x18\x01 \x01(\r\x12\x1a\n\x12\x61uth_change_queued\x18\x02 \x01(\x08\x12\x17\n\x0flowest_sequence\x18\x03 \x01(\r\x12\x18\n\x10highest_sequence\x18\x04 \x01(\r\x12>\n\x15max_spend_drops_total\x18\x05 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.XRPDropsAmount\x12\x38\n\x0ctransactions\x18\x06 \x03(\x0b\x32\".org.xrpl.rpc.v1.QueuedTransaction\"\x97\x02\n\x11QueuedTransaction\x12\x13\n\x0b\x61uth_change\x18\x01 \x01(\x08\x12,\n\x03\x66\x65\x65\x18\x02 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.XRPDropsAmount\x12\x15\n\tfee_level\x18\x03 \x01(\x04\x42\x02\x30\x01\x12\x38\n\x0fmax_spend_drops\x18\x04 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.XRPDropsAmount\x12+\n\x08sequence\x18\x05 \x01(\x0b\x32\x19.org.xrpl.rpc.v1.Sequence\x12\x41\n\x14last_ledger_sequence\x18\x06 \x01(\x0b\x32#.org.xrpl.rpc.v1.LastLedgerSequenceB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2.DESCRIPTOR,])




_GETACCOUNTINFOREQUEST = _descriptor.Descriptor(
  name='GetAccountInfoRequest',
  full_name='org.xrpl.rpc.v1.GetAccountInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='org.xrpl.rpc.v1.GetAccountInfoRequest.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strict', full_name='org.xrpl.rpc.v1.GetAccountInfoRequest.strict', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger', full_name='org.xrpl.rpc.v1.GetAccountInfoRequest.ledger', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='org.xrpl.rpc.v1.GetAccountInfoRequest.queue', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signer_lists', full_name='org.xrpl.rpc.v1.GetAccountInfoRequest.signer_lists', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=219,
  serialized_end=395,
)


_GETACCOUNTINFORESPONSE = _descriptor.Descriptor(
  name='GetAccountInfoResponse',
  full_name='org.xrpl.rpc.v1.GetAccountInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_data', full_name='org.xrpl.rpc.v1.GetAccountInfoResponse.account_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signer_list', full_name='org.xrpl.rpc.v1.GetAccountInfoResponse.signer_list', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_index', full_name='org.xrpl.rpc.v1.GetAccountInfoResponse.ledger_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue_data', full_name='org.xrpl.rpc.v1.GetAccountInfoResponse.queue_data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validated', full_name='org.xrpl.rpc.v1.GetAccountInfoResponse.validated', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=613,
)


_QUEUEDATA = _descriptor.Descriptor(
  name='QueueData',
  full_name='org.xrpl.rpc.v1.QueueData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txn_count', full_name='org.xrpl.rpc.v1.QueueData.txn_count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_change_queued', full_name='org.xrpl.rpc.v1.QueueData.auth_change_queued', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lowest_sequence', full_name='org.xrpl.rpc.v1.QueueData.lowest_sequence', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='highest_sequence', full_name='org.xrpl.rpc.v1.QueueData.highest_sequence', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_spend_drops_total', full_name='org.xrpl.rpc.v1.QueueData.max_spend_drops_total', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transactions', full_name='org.xrpl.rpc.v1.QueueData.transactions', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=847,
)


_QUEUEDTRANSACTION = _descriptor.Descriptor(
  name='QueuedTransaction',
  full_name='org.xrpl.rpc.v1.QueuedTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth_change', full_name='org.xrpl.rpc.v1.QueuedTransaction.auth_change', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee', full_name='org.xrpl.rpc.v1.QueuedTransaction.fee', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee_level', full_name='org.xrpl.rpc.v1.QueuedTransaction.fee_level', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_spend_drops', full_name='org.xrpl.rpc.v1.QueuedTransaction.max_spend_drops', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence', full_name='org.xrpl.rpc.v1.QueuedTransaction.sequence', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_ledger_sequence', full_name='org.xrpl.rpc.v1.QueuedTransaction.last_ledger_sequence', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=850,
  serialized_end=1129,
)

_GETACCOUNTINFOREQUEST.fields_by_name['account'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2._ACCOUNTADDRESS
_GETACCOUNTINFOREQUEST.fields_by_name['ledger'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._LEDGERSPECIFIER
_GETACCOUNTINFORESPONSE.fields_by_name['account_data'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2._ACCOUNTROOT
_GETACCOUNTINFORESPONSE.fields_by_name['signer_list'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2._SIGNERLIST
_GETACCOUNTINFORESPONSE.fields_by_name['queue_data'].message_type = _QUEUEDATA
_QUEUEDATA.fields_by_name['max_spend_drops_total'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._XRPDROPSAMOUNT
_QUEUEDATA.fields_by_name['transactions'].message_type = _QUEUEDTRANSACTION
_QUEUEDTRANSACTION.fields_by_name['fee'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._XRPDROPSAMOUNT
_QUEUEDTRANSACTION.fields_by_name['max_spend_drops'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._XRPDROPSAMOUNT
_QUEUEDTRANSACTION.fields_by_name['sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SEQUENCE
_QUEUEDTRANSACTION.fields_by_name['last_ledger_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._LASTLEDGERSEQUENCE
DESCRIPTOR.message_types_by_name['GetAccountInfoRequest'] = _GETACCOUNTINFOREQUEST
DESCRIPTOR.message_types_by_name['GetAccountInfoResponse'] = _GETACCOUNTINFORESPONSE
DESCRIPTOR.message_types_by_name['QueueData'] = _QUEUEDATA
DESCRIPTOR.message_types_by_name['QueuedTransaction'] = _QUEUEDTRANSACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetAccountInfoRequest = _reflection.GeneratedProtocolMessageType('GetAccountInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTINFOREQUEST,
  '__module__' : 'org.xrpl.rpc.v1.get_account_info_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetAccountInfoRequest)
  })
_sym_db.RegisterMessage(GetAccountInfoRequest)

GetAccountInfoResponse = _reflection.GeneratedProtocolMessageType('GetAccountInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTINFORESPONSE,
  '__module__' : 'org.xrpl.rpc.v1.get_account_info_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetAccountInfoResponse)
  })
_sym_db.RegisterMessage(GetAccountInfoResponse)

QueueData = _reflection.GeneratedProtocolMessageType('QueueData', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEDATA,
  '__module__' : 'org.xrpl.rpc.v1.get_account_info_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.QueueData)
  })
_sym_db.RegisterMessage(QueueData)

QueuedTransaction = _reflection.GeneratedProtocolMessageType('QueuedTransaction', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEDTRANSACTION,
  '__module__' : 'org.xrpl.rpc.v1.get_account_info_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.QueuedTransaction)
  })
_sym_db.RegisterMessage(QueuedTransaction)


DESCRIPTOR._options = None
_QUEUEDTRANSACTION.fields_by_name['fee_level']._options = None
# @@protoc_insertion_point(module_scope)
