# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from .account_pb2 import (
    AccountAddress as org___xrpl___rpc___v1___account_pb2___AccountAddress,
)

from .amount_pb2 import (
    XRPDropsAmount as org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount,
)

from .common_pb2 import (
    LastLedgerSequence as org___xrpl___rpc___v1___common_pb2___LastLedgerSequence,
    Sequence as org___xrpl___rpc___v1___common_pb2___Sequence,
)

from .ledger_objects_pb2 import (
    AccountRoot as org___xrpl___rpc___v1___ledger_objects_pb2___AccountRoot,
    SignerList as org___xrpl___rpc___v1___ledger_objects_pb2___SignerList,
)

from .ledger_pb2 import (
    LedgerSpecifier as org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Union as typing___Union,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


class GetAccountInfoRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    strict = ... # type: builtin___bool
    queue = ... # type: builtin___bool
    signer_lists = ... # type: builtin___bool

    @property
    def account(self) -> org___xrpl___rpc___v1___account_pb2___AccountAddress: ...

    @property
    def ledger(self) -> org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier: ...

    def __init__(self,
        *,
        account : typing___Optional[org___xrpl___rpc___v1___account_pb2___AccountAddress] = None,
        strict : typing___Optional[builtin___bool] = None,
        ledger : typing___Optional[org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier] = None,
        queue : typing___Optional[builtin___bool] = None,
        signer_lists : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> GetAccountInfoRequest: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> GetAccountInfoRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"account",u"ledger"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account",u"ledger",u"queue",u"signer_lists",u"strict"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"account",b"account",u"ledger",b"ledger"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account",b"account",u"ledger",b"ledger",u"queue",b"queue",u"signer_lists",b"signer_lists",u"strict",b"strict"]) -> None: ...

class GetAccountInfoResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ledger_index = ... # type: builtin___int
    validated = ... # type: builtin___bool

    @property
    def account_data(self) -> org___xrpl___rpc___v1___ledger_objects_pb2___AccountRoot: ...

    @property
    def signer_list(self) -> org___xrpl___rpc___v1___ledger_objects_pb2___SignerList: ...

    @property
    def queue_data(self) -> QueueData: ...

    def __init__(self,
        *,
        account_data : typing___Optional[org___xrpl___rpc___v1___ledger_objects_pb2___AccountRoot] = None,
        signer_list : typing___Optional[org___xrpl___rpc___v1___ledger_objects_pb2___SignerList] = None,
        ledger_index : typing___Optional[builtin___int] = None,
        queue_data : typing___Optional[QueueData] = None,
        validated : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> GetAccountInfoResponse: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> GetAccountInfoResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"account_data",u"queue_data",u"signer_list"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account_data",u"ledger_index",u"queue_data",u"signer_list",u"validated"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"account_data",b"account_data",u"queue_data",b"queue_data",u"signer_list",b"signer_list"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account_data",b"account_data",u"ledger_index",b"ledger_index",u"queue_data",b"queue_data",u"signer_list",b"signer_list",u"validated",b"validated"]) -> None: ...

class QueueData(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    txn_count = ... # type: builtin___int
    auth_change_queued = ... # type: builtin___bool
    lowest_sequence = ... # type: builtin___int
    highest_sequence = ... # type: builtin___int

    @property
    def max_spend_drops_total(self) -> org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount: ...

    @property
    def transactions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[QueuedTransaction]: ...

    def __init__(self,
        *,
        txn_count : typing___Optional[builtin___int] = None,
        auth_change_queued : typing___Optional[builtin___bool] = None,
        lowest_sequence : typing___Optional[builtin___int] = None,
        highest_sequence : typing___Optional[builtin___int] = None,
        max_spend_drops_total : typing___Optional[org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount] = None,
        transactions : typing___Optional[typing___Iterable[QueuedTransaction]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> QueueData: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> QueueData: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"max_spend_drops_total"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"auth_change_queued",u"highest_sequence",u"lowest_sequence",u"max_spend_drops_total",u"transactions",u"txn_count"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"max_spend_drops_total",b"max_spend_drops_total"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"auth_change_queued",b"auth_change_queued",u"highest_sequence",b"highest_sequence",u"lowest_sequence",b"lowest_sequence",u"max_spend_drops_total",b"max_spend_drops_total",u"transactions",b"transactions",u"txn_count",b"txn_count"]) -> None: ...

class QueuedTransaction(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    auth_change = ... # type: builtin___bool
    fee_level = ... # type: builtin___int

    @property
    def fee(self) -> org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount: ...

    @property
    def max_spend_drops(self) -> org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount: ...

    @property
    def sequence(self) -> org___xrpl___rpc___v1___common_pb2___Sequence: ...

    @property
    def last_ledger_sequence(self) -> org___xrpl___rpc___v1___common_pb2___LastLedgerSequence: ...

    def __init__(self,
        *,
        auth_change : typing___Optional[builtin___bool] = None,
        fee : typing___Optional[org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount] = None,
        fee_level : typing___Optional[builtin___int] = None,
        max_spend_drops : typing___Optional[org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount] = None,
        sequence : typing___Optional[org___xrpl___rpc___v1___common_pb2___Sequence] = None,
        last_ledger_sequence : typing___Optional[org___xrpl___rpc___v1___common_pb2___LastLedgerSequence] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> QueuedTransaction: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> QueuedTransaction: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"fee",u"last_ledger_sequence",u"max_spend_drops",u"sequence"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"auth_change",u"fee",u"fee_level",u"last_ledger_sequence",u"max_spend_drops",u"sequence"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"fee",b"fee",u"last_ledger_sequence",b"last_ledger_sequence",u"max_spend_drops",b"max_spend_drops",u"sequence",b"sequence"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"auth_change",b"auth_change",u"fee",b"fee",u"fee_level",b"fee_level",u"last_ledger_sequence",b"last_ledger_sequence",u"max_spend_drops",b"max_spend_drops",u"sequence",b"sequence"]) -> None: ...
