# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/meta.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ledger_objects_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2
from . import common_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/meta.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n\x1aorg/xrpl/rpc/v1/meta.proto\x12\x0forg.xrpl.rpc.v1\x1a$org/xrpl/rpc/v1/ledger_objects.proto\x1a\x1corg/xrpl/rpc/v1/common.proto\"\xd8\x01\n\x04Meta\x12\x1d\n\x11transaction_index\x18\x01 \x01(\x04\x42\x02\x30\x01\x12>\n\x12transaction_result\x18\x02 \x01(\x0b\x32\".org.xrpl.rpc.v1.TransactionResult\x12\x35\n\x0e\x61\x66\x66\x65\x63ted_nodes\x18\x03 \x03(\x0b\x32\x1d.org.xrpl.rpc.v1.AffectedNode\x12:\n\x10\x64\x65livered_amount\x18\x04 \x01(\x0b\x32 .org.xrpl.rpc.v1.DeliveredAmount\"\x91\x02\n\x11TransactionResult\x12\x42\n\x0bresult_type\x18\x01 \x01(\x0e\x32-.org.xrpl.rpc.v1.TransactionResult.ResultType\x12\x0e\n\x06result\x18\x02 \x01(\t\"\xa7\x01\n\nResultType\x12\x1b\n\x17RESULT_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fRESULT_TYPE_TEC\x10\x01\x12\x13\n\x0fRESULT_TYPE_TEF\x10\x02\x12\x13\n\x0fRESULT_TYPE_TEL\x10\x03\x12\x13\n\x0fRESULT_TYPE_TEM\x10\x04\x12\x13\n\x0fRESULT_TYPE_TER\x10\x05\x12\x13\n\x0fRESULT_TYPE_TES\x10\x06\"\x8d\x02\n\x0c\x41\x66\x66\x65\x63tedNode\x12;\n\x11ledger_entry_type\x18\x01 \x01(\x0e\x32 .org.xrpl.rpc.v1.LedgerEntryType\x12\x14\n\x0cledger_index\x18\x02 \x01(\x0c\x12\x34\n\x0c\x63reated_node\x18\x03 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.CreatedNodeH\x00\x12\x34\n\x0c\x64\x65leted_node\x18\x04 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.DeletedNodeH\x00\x12\x36\n\rmodified_node\x18\x05 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.ModifiedNodeH\x00\x42\x06\n\x04node\"@\n\x0b\x43reatedNode\x12\x31\n\nnew_fields\x18\x01 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.LedgerObject\"B\n\x0b\x44\x65letedNode\x12\x33\n\x0c\x66inal_fields\x18\x01 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.LedgerObject\"\xa6\x02\n\x0cModifiedNode\x12\x33\n\x0c\x66inal_fields\x18\x01 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.LedgerObject\x12\x36\n\x0fprevious_fields\x18\x02 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.LedgerObject\x12G\n\x17previous_transaction_id\x18\x03 \x01(\x0b\x32&.org.xrpl.rpc.v1.PreviousTransactionID\x12`\n$previous_transaction_ledger_sequence\x18\x04 \x01(\x0b\x32\x32.org.xrpl.rpc.v1.PreviousTransactionLedgerSequenceB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2.DESCRIPTOR,])



_TRANSACTIONRESULT_RESULTTYPE = _descriptor.EnumDescriptor(
  name='ResultType',
  full_name='org.xrpl.rpc.v1.TransactionResult.ResultType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESULT_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESULT_TYPE_TEC', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESULT_TYPE_TEF', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESULT_TYPE_TEL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESULT_TYPE_TEM', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESULT_TYPE_TER', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESULT_TYPE_TES', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=441,
  serialized_end=608,
)
_sym_db.RegisterEnumDescriptor(_TRANSACTIONRESULT_RESULTTYPE)


_META = _descriptor.Descriptor(
  name='Meta',
  full_name='org.xrpl.rpc.v1.Meta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_index', full_name='org.xrpl.rpc.v1.Meta.transaction_index', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_result', full_name='org.xrpl.rpc.v1.Meta.transaction_result', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='affected_nodes', full_name='org.xrpl.rpc.v1.Meta.affected_nodes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delivered_amount', full_name='org.xrpl.rpc.v1.Meta.delivered_amount', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=332,
)


_TRANSACTIONRESULT = _descriptor.Descriptor(
  name='TransactionResult',
  full_name='org.xrpl.rpc.v1.TransactionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result_type', full_name='org.xrpl.rpc.v1.TransactionResult.result_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='org.xrpl.rpc.v1.TransactionResult.result', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRANSACTIONRESULT_RESULTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=608,
)


_AFFECTEDNODE = _descriptor.Descriptor(
  name='AffectedNode',
  full_name='org.xrpl.rpc.v1.AffectedNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_entry_type', full_name='org.xrpl.rpc.v1.AffectedNode.ledger_entry_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_index', full_name='org.xrpl.rpc.v1.AffectedNode.ledger_index', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_node', full_name='org.xrpl.rpc.v1.AffectedNode.created_node', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deleted_node', full_name='org.xrpl.rpc.v1.AffectedNode.deleted_node', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modified_node', full_name='org.xrpl.rpc.v1.AffectedNode.modified_node', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='node', full_name='org.xrpl.rpc.v1.AffectedNode.node',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=611,
  serialized_end=880,
)


_CREATEDNODE = _descriptor.Descriptor(
  name='CreatedNode',
  full_name='org.xrpl.rpc.v1.CreatedNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_fields', full_name='org.xrpl.rpc.v1.CreatedNode.new_fields', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=882,
  serialized_end=946,
)


_DELETEDNODE = _descriptor.Descriptor(
  name='DeletedNode',
  full_name='org.xrpl.rpc.v1.DeletedNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='final_fields', full_name='org.xrpl.rpc.v1.DeletedNode.final_fields', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=948,
  serialized_end=1014,
)


_MODIFIEDNODE = _descriptor.Descriptor(
  name='ModifiedNode',
  full_name='org.xrpl.rpc.v1.ModifiedNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='final_fields', full_name='org.xrpl.rpc.v1.ModifiedNode.final_fields', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_fields', full_name='org.xrpl.rpc.v1.ModifiedNode.previous_fields', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_id', full_name='org.xrpl.rpc.v1.ModifiedNode.previous_transaction_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_ledger_sequence', full_name='org.xrpl.rpc.v1.ModifiedNode.previous_transaction_ledger_sequence', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1017,
  serialized_end=1311,
)

_META.fields_by_name['transaction_result'].message_type = _TRANSACTIONRESULT
_META.fields_by_name['affected_nodes'].message_type = _AFFECTEDNODE
_META.fields_by_name['delivered_amount'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DELIVEREDAMOUNT
_TRANSACTIONRESULT.fields_by_name['result_type'].enum_type = _TRANSACTIONRESULT_RESULTTYPE
_TRANSACTIONRESULT_RESULTTYPE.containing_type = _TRANSACTIONRESULT
_AFFECTEDNODE.fields_by_name['ledger_entry_type'].enum_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2._LEDGERENTRYTYPE
_AFFECTEDNODE.fields_by_name['created_node'].message_type = _CREATEDNODE
_AFFECTEDNODE.fields_by_name['deleted_node'].message_type = _DELETEDNODE
_AFFECTEDNODE.fields_by_name['modified_node'].message_type = _MODIFIEDNODE
_AFFECTEDNODE.oneofs_by_name['node'].fields.append(
  _AFFECTEDNODE.fields_by_name['created_node'])
_AFFECTEDNODE.fields_by_name['created_node'].containing_oneof = _AFFECTEDNODE.oneofs_by_name['node']
_AFFECTEDNODE.oneofs_by_name['node'].fields.append(
  _AFFECTEDNODE.fields_by_name['deleted_node'])
_AFFECTEDNODE.fields_by_name['deleted_node'].containing_oneof = _AFFECTEDNODE.oneofs_by_name['node']
_AFFECTEDNODE.oneofs_by_name['node'].fields.append(
  _AFFECTEDNODE.fields_by_name['modified_node'])
_AFFECTEDNODE.fields_by_name['modified_node'].containing_oneof = _AFFECTEDNODE.oneofs_by_name['node']
_CREATEDNODE.fields_by_name['new_fields'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2._LEDGEROBJECT
_DELETEDNODE.fields_by_name['final_fields'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2._LEDGEROBJECT
_MODIFIEDNODE.fields_by_name['final_fields'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2._LEDGEROBJECT
_MODIFIEDNODE.fields_by_name['previous_fields'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2._LEDGEROBJECT
_MODIFIEDNODE.fields_by_name['previous_transaction_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONID
_MODIFIEDNODE.fields_by_name['previous_transaction_ledger_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONLEDGERSEQUENCE
DESCRIPTOR.message_types_by_name['Meta'] = _META
DESCRIPTOR.message_types_by_name['TransactionResult'] = _TRANSACTIONRESULT
DESCRIPTOR.message_types_by_name['AffectedNode'] = _AFFECTEDNODE
DESCRIPTOR.message_types_by_name['CreatedNode'] = _CREATEDNODE
DESCRIPTOR.message_types_by_name['DeletedNode'] = _DELETEDNODE
DESCRIPTOR.message_types_by_name['ModifiedNode'] = _MODIFIEDNODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Meta = _reflection.GeneratedProtocolMessageType('Meta', (_message.Message,), {
  'DESCRIPTOR' : _META,
  '__module__' : 'org.xrpl.rpc.v1.meta_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Meta)
  })
_sym_db.RegisterMessage(Meta)

TransactionResult = _reflection.GeneratedProtocolMessageType('TransactionResult', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONRESULT,
  '__module__' : 'org.xrpl.rpc.v1.meta_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TransactionResult)
  })
_sym_db.RegisterMessage(TransactionResult)

AffectedNode = _reflection.GeneratedProtocolMessageType('AffectedNode', (_message.Message,), {
  'DESCRIPTOR' : _AFFECTEDNODE,
  '__module__' : 'org.xrpl.rpc.v1.meta_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.AffectedNode)
  })
_sym_db.RegisterMessage(AffectedNode)

CreatedNode = _reflection.GeneratedProtocolMessageType('CreatedNode', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDNODE,
  '__module__' : 'org.xrpl.rpc.v1.meta_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.CreatedNode)
  })
_sym_db.RegisterMessage(CreatedNode)

DeletedNode = _reflection.GeneratedProtocolMessageType('DeletedNode', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDNODE,
  '__module__' : 'org.xrpl.rpc.v1.meta_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.DeletedNode)
  })
_sym_db.RegisterMessage(DeletedNode)

ModifiedNode = _reflection.GeneratedProtocolMessageType('ModifiedNode', (_message.Message,), {
  'DESCRIPTOR' : _MODIFIEDNODE,
  '__module__' : 'org.xrpl.rpc.v1.meta_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.ModifiedNode)
  })
_sym_db.RegisterMessage(ModifiedNode)


DESCRIPTOR._options = None
_META.fields_by_name['transaction_index']._options = None
# @@protoc_insertion_point(module_scope)
