# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/xrp_ledger.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import get_account_info_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__info__pb2
from . import get_fee_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__fee__pb2
from . import submit_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_submit__pb2
from . import get_transaction_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2
from . import get_account_transaction_history_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__transaction__history__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/xrp_ledger.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n org/xrpl/rpc/v1/xrp_ledger.proto\x12\x0forg.xrpl.rpc.v1\x1a&org/xrpl/rpc/v1/get_account_info.proto\x1a\x1dorg/xrpl/rpc/v1/get_fee.proto\x1a\x1corg/xrpl/rpc/v1/submit.proto\x1a%org/xrpl/rpc/v1/get_transaction.proto\x1a\x35org/xrpl/rpc/v1/get_account_transaction_history.proto2\xa0\x04\n\x13XRPLedgerAPIService\x12\x61\n\x0eGetAccountInfo\x12&.org.xrpl.rpc.v1.GetAccountInfoRequest\x1a\'.org.xrpl.rpc.v1.GetAccountInfoResponse\x12I\n\x06GetFee\x12\x1e.org.xrpl.rpc.v1.GetFeeRequest\x1a\x1f.org.xrpl.rpc.v1.GetFeeResponse\x12j\n\x11SubmitTransaction\x12).org.xrpl.rpc.v1.SubmitTransactionRequest\x1a*.org.xrpl.rpc.v1.SubmitTransactionResponse\x12\x61\n\x0eGetTransaction\x12&.org.xrpl.rpc.v1.GetTransactionRequest\x1a\'.org.xrpl.rpc.v1.GetTransactionResponse\x12\x8b\x01\n\x1cGetAccountTransactionHistory\x12\x34.org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest\x1a\x35.org.xrpl.rpc.v1.GetAccountTransactionHistoryResponseB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__info__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_get__fee__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_submit__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__transaction__history__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_XRPLEDGERAPISERVICE = _descriptor.ServiceDescriptor(
  name='XRPLedgerAPIService',
  full_name='org.xrpl.rpc.v1.XRPLedgerAPIService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=249,
  serialized_end=793,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAccountInfo',
    full_name='org.xrpl.rpc.v1.XRPLedgerAPIService.GetAccountInfo',
    index=0,
    containing_service=None,
    input_type=org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__info__pb2._GETACCOUNTINFOREQUEST,
    output_type=org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__info__pb2._GETACCOUNTINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetFee',
    full_name='org.xrpl.rpc.v1.XRPLedgerAPIService.GetFee',
    index=1,
    containing_service=None,
    input_type=org_dot_xrpl_dot_rpc_dot_v1_dot_get__fee__pb2._GETFEEREQUEST,
    output_type=org_dot_xrpl_dot_rpc_dot_v1_dot_get__fee__pb2._GETFEERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SubmitTransaction',
    full_name='org.xrpl.rpc.v1.XRPLedgerAPIService.SubmitTransaction',
    index=2,
    containing_service=None,
    input_type=org_dot_xrpl_dot_rpc_dot_v1_dot_submit__pb2._SUBMITTRANSACTIONREQUEST,
    output_type=org_dot_xrpl_dot_rpc_dot_v1_dot_submit__pb2._SUBMITTRANSACTIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTransaction',
    full_name='org.xrpl.rpc.v1.XRPLedgerAPIService.GetTransaction',
    index=3,
    containing_service=None,
    input_type=org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2._GETTRANSACTIONREQUEST,
    output_type=org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2._GETTRANSACTIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAccountTransactionHistory',
    full_name='org.xrpl.rpc.v1.XRPLedgerAPIService.GetAccountTransactionHistory',
    index=4,
    containing_service=None,
    input_type=org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__transaction__history__pb2._GETACCOUNTTRANSACTIONHISTORYREQUEST,
    output_type=org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__transaction__history__pb2._GETACCOUNTTRANSACTIONHISTORYRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_XRPLEDGERAPISERVICE)

DESCRIPTOR.services_by_name['XRPLedgerAPIService'] = _XRPLEDGERAPISERVICE

# @@protoc_insertion_point(module_scope)
